# Shell Command Launcher

A simple tool to launch shell command many times.

````{grid} 2
:gutter: 3

  ```{grid-item-card} Installation Guides

  Get started by installing Shell Command Launcher.

  +++

    ```{button-ref} get_started/installation
    :expand:
    :color: secondary
    :click-parent:

    To the installation guides
    ```
  ```

  ```{grid-item-card} Usage Guides

  Details of the core features provide by Shell Command Launcher.

  +++

    ```{button-ref} get_started/usage
    :expand:
    :color: secondary
    :click-parent:

    To the Usage guides
    ```
  ```

  ```{grid-item-card} API Reference Guides

  References of the API provided by Shell Command Launcher.

  +++

    ```{button-ref} autoapi/shell_command_launcher/index
    :expand:
    :color: secondary
    :click-parent:

    To the API Reference guides
    ```
  ```

  ```{grid-item-card} Contribution Guides

  Helpful instruction to develop Shell Command Launcher.

  +++

    ```{button-ref} get_started/contribution
    :expand:
    :color: secondary
    :click-parent:

    To the Contribution guides
    ```
  ```
````

```{toctree}
:hidden:
:caption: Get Started

get_started/installation
get_started/usage
get_started/contribution
get_started/changelog
```

```{toctree}
:hidden:
:caption: API References

autoapi/shell_command_launcher/index
```
